@@ -2,68 +2,68 @@ info = {
     "name": "lo",
     "date_order": "DMY",
     "january": [
-        "ມັງກອນ",
-        "ມກ"
+        "ມກ",
+        "ມັງກອນ"
     ],
     "february": [
-        "ກຸມພາ",
-        "ກພ"
+        "ກພ",
+        "ກຸມພາ"
     ],
     "march": [
-        "ມີນາ",
-        "ມນ"
+        "ມນ",
+        "ມີນາ"
     ],
     "april": [
-        "ເມສາ",
-        "ມສ"
+        "ມສ",
+        "ເມສາ"
     ],
     "may": [
-        "ພຶດສະພາ",
-        "ພພ"
+        "ພພ",
+        "ພຶດສະພາ"
     ],
     "june": [
-        "ມິຖຸນາ",
-        "ມິຖ"
+        "ມິຖ",
+        "ມິຖຸນາ"
     ],
     "july": [
-        "ກໍລະກົດ",
-        "ກລ"
+        "ກລ",
+        "ກໍລະກົດ"
     ],
     "august": [
-        "ສິງຫາ",
-        "ສຫ"
+        "ສຫ",
+        "ສິງຫາ"
     ],
     "september": [
-        "ກັນຍາ",
-        "ກຍ"
+        "ກຍ",
+        "ກັນຍາ"
     ],
     "october": [
-        "ຕຸລາ",
-        "ຕລ"
+        "ຕລ",
+        "ຕຸລາ"
     ],
     "november": [
-        "ພະຈິກ",
-        "ພຈ"
+        "ພຈ",
+        "ພະຈິກ"
     ],
     "december": [
-        "ທັນວາ",
-        "ທວ"
+        "ທວ",
+        "ທັນວາ"
     ],
     "monday": [
-        "ວັນຈັນ",
-        "ຈັນ"
+        "ຈັນ",
+        "ວັນຈັນ"
     ],
     "tuesday": [
         "ວັນອັງຄານ",
         "ອັງຄານ"
     ],
     "wednesday": [
-        "ວັນພຸດ",
-        "ພຸດ"
+        "ພຸດ",
+        "ວັນພຸດ"
     ],
     "thursday": [
-        "ວັນພະຫັດ",
-        "ພະຫັດ"
+        "ພະຫັດ",
+        "ວັນພະຫັດ"
     ],
     "friday": [
         "ວັນສຸກ",
@@ -87,142 +87,142 @@ info = {
         "ປີ"
     ],
     "month": [
-        "ເດືອນ",
-        "ດ"
+        "ດ",
+        "ເດືອນ"
     ],
     "week": [
-        "ອາທິດ",
-        "ອ"
+        "ອ",
+        "ອາທິດ"
     ],
     "day": [
         "ມື້"
     ],
     "hour": [
-        "ຊົ່ວໂມງ",
-        "ຊມ"
+        "ຊມ",
+        "ຊົ່ວໂມງ"
     ],
     "minute": [
-        "ນາທີ",
-        "ນທ"
+        "ນທ",
+        "ນາທີ"
     ],
     "second": [
-        "ວິນາທີ",
-        "ວິ"
+        "ວິ",
+        "ວິນາທີ"
     ],
     "relative-type": {
-        "1 year ago": [
-            "ປີກາຍ"
-        ],
-        "0 year ago": [
-            "ປີນີ້"
-        ],
-        "in 1 year": [
-            "ປີໜ້າ"
-        ],
-        "1 month ago": [
-            "ເດືອນແລ້ວ"
-        ],
-        "0 month ago": [
-            "ເດືອນນີ້"
-        ],
-        "in 1 month": [
-            "ເດືອນໜ້າ"
-        ],
-        "1 week ago": [
-            "ອາທິດແລ້ວ"
-        ],
-        "0 week ago": [
-            "ອາທິດນີ້"
-        ],
-        "in 1 week": [
-            "ອາທິດໜ້າ"
-        ],
-        "1 day ago": [
-            "ມື້ວານ"
-        ],
         "0 day ago": [
             "ມື້ນີ້"
         ],
-        "in 1 day": [
-            "ມື້ອື່ນ"
-        ],
         "0 hour ago": [
             "ຊົ່ວໂມງນີ້"
         ],
         "0 minute ago": [
             "ນາທີນີ້"
         ],
+        "0 month ago": [
+            "ເດືອນນີ້"
+        ],
         "0 second ago": [
             "ຕອນນີ້"
+        ],
+        "0 week ago": [
+            "ອາທິດນີ້"
+        ],
+        "0 year ago": [
+            "ປີນີ້"
+        ],
+        "1 day ago": [
+            "ມື້ວານ"
+        ],
+        "1 month ago": [
+            "ເດືອນແລ້ວ"
+        ],
+        "1 week ago": [
+            "ອາທິດແລ້ວ"
+        ],
+        "1 year ago": [
+            "ປີກາຍ"
+        ],
+        "in 1 day": [
+            "ມື້ອື່ນ"
+        ],
+        "in 1 month": [
+            "ເດືອນໜ້າ"
+        ],
+        "in 1 week": [
+            "ອາທິດໜ້າ"
+        ],
+        "in 1 year": [
+            "ປີໜ້າ"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "ໃນອີກ (\\d+) ປີ"
+        "\\1 day ago": [
+            "(\\d+) ມື້ກ່ອນ"
+        ],
+        "\\1 hour ago": [
+            "(\\d+) ຊມ ກ່ອນ",
+            "(\\d+) ຊົ່ວໂມງກ່ອນ"
+        ],
+        "\\1 minute ago": [
+            "(\\d+) ນທ ກ່ອນ",
+            "(\\d+) ນາທີກ່ອນ"
+        ],
+        "\\1 month ago": [
+            "(\\d+) ດ ກ່ອນ",
+            "(\\d+) ເດືອນກ່ອນ"
+        ],
+        "\\1 second ago": [
+            "(\\d+) ວິ ກ່ອນ",
+            "(\\d+) ວິນາທີກ່ອນ"
+        ],
+        "\\1 week ago": [
+            "(\\d+) ອທ ກ່ອນ",
+            "(\\d+) ອາທິດກ່ອນ"
         ],
         "\\1 year ago": [
             "(\\d+) ປີກ່ອນ"
         ],
-        "in \\1 month": [
-            "ໃນອີກ (\\d+) ເດືອນ",
-            "ໃນອີກ (\\d+) ດ"
-        ],
-        "\\1 month ago": [
-            "(\\d+) ເດືອນກ່ອນ",
-            "(\\d+) ດ ກ່ອນ"
-        ],
-        "in \\1 week": [
-            "ໃນອີກ (\\d+) ອາທິດ",
-            "ໃນອີກ (\\d+) ອທ"
-        ],
-        "\\1 week ago": [
-            "(\\d+) ອາທິດກ່ອນ",
-            "(\\d+) ອທ ກ່ອນ"
-        ],
         "in \\1 day": [
             "ໃນອີກ (\\d+) ມື້"
         ],
-        "\\1 day ago": [
-            "(\\d+) ມື້ກ່ອນ"
-        ],
         "in \\1 hour": [
-            "ໃນອີກ (\\d+) ຊົ່ວໂມງ",
-            "ໃນອີກ (\\d+) ຊມ"
-        ],
-        "\\1 hour ago": [
-            "(\\d+) ຊົ່ວໂມງກ່ອນ",
-            "(\\d+) ຊມ ກ່ອນ"
+            "ໃນອີກ (\\d+) ຊມ",
+            "ໃນອີກ (\\d+) ຊົ່ວໂມງ"
         ],
         "in \\1 minute": [
             "(\\d+) ໃນອີກ 0 ນາທີ",
             "ໃນ (\\d+) ນທ"
         ],
-        "\\1 minute ago": [
-            "(\\d+) ນາທີກ່ອນ",
-            "(\\d+) ນທ ກ່ອນ"
+        "in \\1 month": [
+            "ໃນອີກ (\\d+) ດ",
+            "ໃນອີກ (\\d+) ເດືອນ"
         ],
         "in \\1 second": [
-            "ໃນອີກ (\\d+) ວິນາທີ",
-            "ໃນ (\\d+) ວິ"
+            "ໃນ (\\d+) ວິ",
+            "ໃນອີກ (\\d+) ວິນາທີ"
         ],
-        "\\1 second ago": [
-            "(\\d+) ວິນາທີກ່ອນ",
-            "(\\d+) ວິ ກ່ອນ"
+        "in \\1 week": [
+            "ໃນອີກ (\\d+) ອທ",
+            "ໃນອີກ (\\d+) ອາທິດ"
+        ],
+        "in \\1 year": [
+            "ໃນອີກ (\\d+) ປີ"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
