@@ -2,19 +2,19 @@ info = {
     "name": "my",
     "date_order": "DMY",
     "january": [
-        "ဇန်နဝါရီ",
-        "ဇန်"
+        "ဇန်",
+        "ဇန်နဝါရီ"
     ],
     "february": [
-        "ဖေဖော်ဝါရီ",
-        "ဖေ"
+        "ဖေ",
+        "ဖေဖော်ဝါရီ"
     ],
     "march": [
         "မတ်"
     ],
     "april": [
-        "ဧပြီ",
-        "ဧ"
+        "ဧ",
+        "ဧပြီ"
     ],
     "may": [
         "မေ"
@@ -23,28 +23,28 @@ info = {
         "ဇွန်"
     ],
     "july": [
-        "ဇူလိုင်",
-        "ဇူ"
+        "ဇူ",
+        "ဇူလိုင်"
     ],
     "august": [
-        "ဩဂုတ်",
-        "ဩ"
+        "ဩ",
+        "ဩဂုတ်"
     ],
     "september": [
-        "စက်တင်ဘာ",
-        "စက်"
+        "စက်",
+        "စက်တင်ဘာ"
     ],
     "october": [
-        "အောက်တိုဘာ",
-        "အောက်"
+        "အောက်",
+        "အောက်တိုဘာ"
     ],
     "november": [
-        "နိုဝင်ဘာ",
-        "နို"
+        "နို",
+        "နိုဝင်ဘာ"
     ],
     "december": [
-        "ဒီဇင်ဘာ",
-        "ဒီ"
+        "ဒီ",
+        "ဒီဇင်ဘာ"
     ],
     "monday": [
         "တနင်္လာ"
@@ -95,109 +95,109 @@ info = {
         "စက္ကန့်"
     ],
     "relative-type": {
-        "1 year ago": [
-            "ယမန်နှစ်"
-        ],
-        "0 year ago": [
-            "ယခုနှစ်"
-        ],
-        "in 1 year": [
-            "လာမည့်နှစ်"
-        ],
-        "1 month ago": [
-            "ပြီးခဲ့သည့်လ"
-        ],
-        "0 month ago": [
-            "ယခုလ"
-        ],
-        "in 1 month": [
-            "လာမည့်လ"
-        ],
-        "1 week ago": [
-            "ပြီးခဲ့သည့် သီတင်းပတ်"
-        ],
-        "0 week ago": [
-            "ယခု သီတင်းပတ်"
-        ],
-        "in 1 week": [
-            "လာမည့် သီတင်းပတ်"
-        ],
-        "1 day ago": [
-            "မနေ့က"
-        ],
         "0 day ago": [
             "ယနေ့"
         ],
-        "in 1 day": [
-            "မနက်ဖြန်"
-        ],
         "0 hour ago": [
             "ဤအချိန်"
         ],
         "0 minute ago": [
             "ဤမိနစ်"
         ],
+        "0 month ago": [
+            "ယခုလ"
+        ],
         "0 second ago": [
             "ယခု"
+        ],
+        "0 week ago": [
+            "ယခု သီတင်းပတ်"
+        ],
+        "0 year ago": [
+            "ယခုနှစ်"
+        ],
+        "1 day ago": [
+            "မနေ့က"
+        ],
+        "1 month ago": [
+            "ပြီးခဲ့သည့်လ"
+        ],
+        "1 week ago": [
+            "ပြီးခဲ့သည့် သီတင်းပတ်"
+        ],
+        "1 year ago": [
+            "ယမန်နှစ်"
+        ],
+        "in 1 day": [
+            "မနက်ဖြန်"
+        ],
+        "in 1 month": [
+            "လာမည့်လ"
+        ],
+        "in 1 week": [
+            "လာမည့် သီတင်းပတ်"
+        ],
+        "in 1 year": [
+            "လာမည့်နှစ်"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) နှစ်အတွင်း"
-        ],
-        "\\1 year ago": [
-            "ပြီးခဲ့သည့် (\\d+) နှစ်"
-        ],
-        "in \\1 month": [
-            "(\\d+) လအတွင်း"
-        ],
-        "\\1 month ago": [
-            "ပြီးခဲ့သည့် (\\d+) လ"
-        ],
-        "in \\1 week": [
-            "(\\d+) ပတ်အတွင်း"
-        ],
-        "\\1 week ago": [
-            "ပြီးခဲ့သည့် (\\d+) ပတ်"
-        ],
-        "in \\1 day": [
-            "(\\d+) ရက်အတွင်း"
-        ],
         "\\1 day ago": [
             "ပြီးခဲ့သည့် (\\d+) ရက်"
         ],
-        "in \\1 hour": [
-            "(\\d+) နာရီအတွင်း"
-        ],
         "\\1 hour ago": [
             "ပြီးခဲ့သည့် (\\d+) နာရီ"
         ],
+        "\\1 minute ago": [
+            "ပြီးခဲ့သည့် (\\d+) မိနစ်"
+        ],
+        "\\1 month ago": [
+            "ပြီးခဲ့သည့် (\\d+) လ"
+        ],
+        "\\1 second ago": [
+            "ပြီးခဲ့သည့် (\\d+) စက္ကန့်"
+        ],
+        "\\1 week ago": [
+            "ပြီးခဲ့သည့် (\\d+) ပတ်"
+        ],
+        "\\1 year ago": [
+            "ပြီးခဲ့သည့် (\\d+) နှစ်"
+        ],
+        "in \\1 day": [
+            "(\\d+) ရက်အတွင်း"
+        ],
+        "in \\1 hour": [
+            "(\\d+) နာရီအတွင်း"
+        ],
         "in \\1 minute": [
             "(\\d+) မိနစ်အတွင်း"
         ],
-        "\\1 minute ago": [
-            "ပြီးခဲ့သည့် (\\d+) မိနစ်"
+        "in \\1 month": [
+            "(\\d+) လအတွင်း"
         ],
         "in \\1 second": [
             "(\\d+) စက္ကန့်အတွင်း"
         ],
-        "\\1 second ago": [
-            "ပြီးခဲ့သည့် (\\d+) စက္ကန့်"
+        "in \\1 week": [
+            "(\\d+) ပတ်အတွင်း"
+        ],
+        "in \\1 year": [
+            "(\\d+) နှစ်အတွင်း"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
