@@ -14,6 +14,7 @@ from dateparser.parser import _parse_absolute, _parse_nospaces
 from dateparser.timezone_parser import pop_tz_offset_from_string
 from dateparser.utils import apply_timezone_from_settings, \
     set_correct_day_from_settings
+from dateparser.custom_language_detection.language_mapping import map_languages
 
 APOSTROPHE_LOOK_ALIKE_CHARS = [
     '\N{RIGHT SINGLE QUOTATION MARK}',     # '\u2019'
@@ -106,9 +107,8 @@ def sanitize_date(date_string):
     date_string = RE_SANITIZE_PERIOD.sub('', date_string)
     date_string = RE_SANITIZE_ON.sub(r'\1', date_string)
     date_string = RE_TRIM_COLONS.sub(r'\1', date_string)
-
     date_string = RE_SANITIZE_APOSTROPHE.sub("'", date_string)
-
+    date_string = date_string.strip()
     return date_string
 
 
@@ -188,7 +188,7 @@ class _DateLocaleParser:
     def _try_timestamp(self):
         return DateData(
             date_obj=get_date_from_timestamp(self.date_string, self._settings),
-            period='day',
+            period='time' if self._settings.RETURN_TIME_AS_PERIOD else 'day',
         )
 
     def _try_freshness_parser(self):
@@ -322,6 +322,12 @@ class DateDataParser:
         Configure customized behavior using settings defined in :mod:`dateparser.conf.Settings`.
     :type settings: dict
 
+    :param detect_languages_function:
+        A function for language detection that takes as input a `text` and a `confidence_threshold`,
+        and returns a list of detected language codes.
+        Note: this function is only used if ``languages`` and ``locales`` are not provided.
+    :type detect_languages_function: function
+
     :return: A parser instance
 
     :raises:
@@ -333,7 +339,7 @@ class DateDataParser:
 
     @apply_settings
     def __init__(self, languages=None, locales=None, region=None, try_previous_locales=False,
-                 use_given_order=False, settings=None):
+                 use_given_order=False, settings=None, detect_languages_function=None):
 
         if languages is not None and not isinstance(languages, (list, tuple, Set)):
             raise TypeError("languages argument must be a list (%r given)" % type(languages))
@@ -360,10 +366,11 @@ class DateDataParser:
         self._settings = settings
         self.try_previous_locales = try_previous_locales
         self.use_given_order = use_given_order
-        self.languages = languages
+        self.languages = list(languages) if languages else None
         self.locales = locales
         self.region = region
-        self.previous_locales = set()
+        self.detect_languages_function = detect_languages_function
+        self.previous_locales = collections.OrderedDict()
 
     def get_date_data(self, date_string, date_formats=None):
         """
@@ -401,7 +408,7 @@ class DateDataParser:
             DateData(date_obj=datetime.datetime(2014, 6, 16, 0, 0), period='year', locale='en')
 
         Dates with time zone indications or UTC offsets are returned in UTC time unless
-        specified using `Settings`_.
+        specified using `Settings <https://dateparser.readthedocs.io/en/latest/settings.html#settings>`__.
 
             >>> DateDataParser().get_date_data('23 March 2000, 1:21 PM CET')
             DateData(date_obj=datetime.datetime(2000, 3, 23, 13, 21, tzinfo=<StaticTzInfo 'CET'>),
@@ -423,7 +430,7 @@ class DateDataParser:
             if parsed_date:
                 parsed_date['locale'] = locale.shortname
                 if self.try_previous_locales:
-                    self.previous_locales.add(locale)
+                    self.previous_locales[locale] = None
                 return parsed_date
         else:
             return DateData(date_obj=None, period='day', locale=None)
@@ -457,11 +464,18 @@ class DateDataParser:
                 yield stripped_date_string
 
         if self.try_previous_locales:
-            for locale in self.previous_locales:
+            for locale in self.previous_locales.keys():
                 for s in date_strings():
                     if self._is_applicable_locale(locale, s):
                         yield locale
 
+        if self.detect_languages_function and not self.languages and not self.locales:
+            detected_languages = self.detect_languages_function(
+                text=date_string, confidence_threshold=self._settings.LANGUAGE_DETECTION_CONFIDENCE_THRESHOLD
+            )
+
+            self.languages = map_languages(detected_languages)
+
         for locale in self._get_locale_loader().get_locales(
                 languages=self.languages, locales=self.locales, region=self.region,
                 use_given_order=self.use_given_order):
@@ -469,6 +483,13 @@ class DateDataParser:
                 if self._is_applicable_locale(locale, s):
                     yield locale
 
+        if self._settings.DEFAULT_LANGUAGES:
+            for locale in self._get_locale_loader().get_locales(
+                languages=self._settings.DEFAULT_LANGUAGES, locales=None,
+                region=self.region, use_given_order=self.use_given_order
+            ):
+                yield locale
+
     def _is_applicable_locale(self, locale, date_string):
         return locale.is_applicable(
             date_string,
