@@ -410,6 +410,14 @@ class TestDateDataParser(BaseTestCase):
         self.when_date_string_is_parsed('2020-05-01')
         self.then_detected_locale('es')
 
+    def test_try_previous_locales_order_deterministic(self):
+        self.given_parser(try_previous_locales=True)
+        self.when_date_string_is_parsed('Mañana')  # es
+        self.then_detected_locale('es')
+        self.when_date_string_is_parsed('Понедельник')  # ru
+        self.then_detected_locale('ru')
+        self.then_previous_locales_is(["es", "ru"])
+
     @parameterized.expand([
         param("2014-10-09T17:57:39+00:00"),
     ])
@@ -583,6 +591,10 @@ class TestDateDataParser(BaseTestCase):
     def then_returned_tuple_is(self, expected_tuple):
         self.assertEqual(expected_tuple, self.result)
 
+    def then_previous_locales_is(self, expected_list):
+        self.assertEqual(expected_list,
+                         [locale.shortname for locale in self.parser.previous_locales])
+
 
 class TestParserInitialization(BaseTestCase):
     def setUp(self):
@@ -657,8 +669,10 @@ class TestParserInitialization(BaseTestCase):
 
 class TestSanitizeDate(BaseTestCase):
     def test_remove_year_in_russian(self):
-        self.assertEqual(date.sanitize_date('2005г.'), '2005 ')
-        self.assertEqual(date.sanitize_date('2005 г.'), '2005 ')
+        self.assertEqual(date.sanitize_date('2005г.'), '2005')
+        self.assertEqual(date.sanitize_date('2005г. 20:37'), '2005 20:37')
+        self.assertEqual(date.sanitize_date('2005 г.'), '2005')
+        self.assertEqual(date.sanitize_date('2005 г. 15:24'), '2005 15:24')
         self.assertEqual(date.sanitize_date('Авг.'), 'Авг')
 
     def test_sanitize_date_colons(self):
